==> jc-1.4.0.tar.gz: java/lang/VMObject.c <==
// final class java.lang.VMObject

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 9b667b09132be893 java_lang_Cloneable
// @dep_class 252c536250e0b800 java_lang_IllegalMonitorStateException
// @dep_class dd778e751571cfa9 java_lang_InterruptedException
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 1f3c3a590189dfc9 java_lang_VMObject

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_Cloneable
// @dep_header java_lang_IllegalMonitorStateException
// @dep_header java_lang_InterruptedException
// @dep_header java_lang_String
// @dep_header java_lang_VMObject

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/Cloneable.h"
#include "java/lang/IllegalMonitorStateException.h"
#include "java/lang/InterruptedException.h"
#include "java/lang/String.h"
#include "java/lang/VMObject.h"

/************************************************************************
 *			      Static methods				*
 ************************************************************************/

//
// static final native java.lang.Object clone(java.lang.Cloneable)
//

static const unsigned char _jc_java_lang_VMObject$param_ptypes$clone$3943fce805d80b70[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_java_lang_VMObject$param_types$clone$3943fce805d80b70[] = {
	&_jc_java_lang_Cloneable$type
};

_jc_method _jc_java_lang_VMObject$method_info$clone$3943fce805d80b70 = {
	.name=			"clone",
	.signature=		"(Ljava/lang/Cloneable;)Ljava/lang/Object;",
	.class=			&_jc_java_lang_VMObject$type,
	.param_types=		&_jc_java_lang_VMObject$param_types$clone$3943fce805d80b70,
	.return_type=		&_jc_java_lang_Object$type,
	.param_ptypes=		&_jc_java_lang_VMObject$param_ptypes$clone$3943fce805d80b70,
	.signature_hash=	_JC_JLONG(0x3943fce805d80b70),
	.access_flags=		_JC_ACC_STATIC|_JC_ACC_FINAL|_JC_ACC_NATIVE,
	.function=		&_jc_java_lang_VMObject$method$clone$3943fce805d80b70,
	.num_parameters=	1,
};

_jc_java_lang_Object$object *
_jc_java_lang_VMObject$method$clone$3943fce805d80b70(_jc_env *const env, _jc_object *param0)
{
	_jc_value retval;

	_JC_INVOKE_NATIVE_METHOD(env, &_jc_java_lang_VMObject$method_info$clone$3943fce805d80b70, &retval, param0);
	return retval.l;
}

//
// static final native void notify(java.lang.Object) throws java.lang.IllegalMonitorStateException
//

static const unsigned char _jc_java_lang_VMObject$param_ptypes$notify$9552b108446647d4[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_java_lang_VMObject$exceptions$notify$9552b108446647d4[] = {
	&_jc_java_lang_IllegalMonitorStateException$type
};

static _jc_type *const _jc_java_lang_VMObject$param_types$notify$9552b108446647d4[] = {
	&_jc_java_lang_Object$type
};

_jc_method _jc_java_lang_VMObject$method_info$notify$9552b108446647d4 = {
	.name=			"notify",
	.signature=		"(Ljava/lang/Object;)V",
	.class=			&_jc_java_lang_VMObject$type,
	.param_types=		&_jc_java_lang_VMObject$param_types$notify$9552b108446647d4,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_lang_VMObject$param_ptypes$notify$9552b108446647d4,
	.signature_hash=	_JC_JLONG(0x9552b108446647d4),
	.access_flags=		_JC_ACC_STATIC|_JC_ACC_FINAL|_JC_ACC_NATIVE,
	.function=		&_jc_java_lang_VMObject$method$notify$9552b108446647d4,
	.num_parameters=	1,
	.num_exceptions=	1,
	.exceptions=		&_jc_java_lang_VMObject$exceptions$notify$9552b108446647d4,
};

void
_jc_java_lang_VMObject$method$notify$9552b108446647d4(_jc_env *const env, _jc_java_lang_Object$object *param0)
{
	_jc_value retval;

	_JC_INVOKE_NATIVE_METHOD(env, &_jc_java_lang_VMObject$method_info$notify$9552b108446647d4, &retval, param0);
}

//
// static final native void notifyAll(java.lang.Object) throws java.lang.IllegalMonitorStateException
//

static const unsigned char _jc_java_lang_VMObject$param_ptypes$notifyAll$82e8779c36c7e7ef[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_java_lang_VMObject$exceptions$notifyAll$82e8779c36c7e7ef[] = {
	&_jc_java_lang_IllegalMonitorStateException$type
};

static _jc_type *const _jc_java_lang_VMObject$param_types$notifyAll$82e8779c36c7e7ef[] = {
	&_jc_java_lang_Object$type
};

_jc_method _jc_java_lang_VMObject$method_info$notifyAll$82e8779c36c7e7ef = {
	.name=			"notifyAll",
	.signature=		"(Ljava/lang/Object;)V",
	.class=			&_jc_java_lang_VMObject$type,
	.param_types=		&_jc_java_lang_VMObject$param_types$notifyAll$82e8779c36c7e7ef,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_lang_VMObject$param_ptypes$notifyAll$82e8779c36c7e7ef,
	.signature_hash=	_JC_JLONG(0x82e8779c36c7e7ef),
	.access_flags=		_JC_ACC_STATIC|_JC_ACC_FINAL|_JC_ACC_NATIVE,
	.function=		&_jc_java_lang_VMObject$method$notifyAll$82e8779c36c7e7ef,
	.num_parameters=	1,
	.num_exceptions=	1,
	.exceptions=		&_jc_java_lang_VMObject$exceptions$notifyAll$82e8779c36c7e7ef,
};

void
_jc_java_lang_VMObject$method$notifyAll$82e8779c36c7e7ef(_jc_env *const env, _jc_java_lang_Object$object *param0)
{
	_jc_value retval;

	_JC_INVOKE_NATIVE_METHOD(env, &_jc_java_lang_VMObject$method_info$notifyAll$82e8779c36c7e7ef, &retval, param0);
}

//
// static final native void wait(java.lang.Object, long, int) throws java.lang.IllegalMonitorStateException, java.lang.InterruptedException
//

static const unsigned char _jc_java_lang_VMObject$param_ptypes$wait$f4b3db53c17f3f59[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_LONG, _JC_TYPE_INT, _JC_TYPE_VOID };

static _jc_type *const _jc_java_lang_VMObject$exceptions$wait$f4b3db53c17f3f59[] = {
	&_jc_java_lang_IllegalMonitorStateException$type,
	&_jc_java_lang_InterruptedException$type
};

static _jc_type *const _jc_java_lang_VMObject$param_types$wait$f4b3db53c17f3f59[] = {
	&_jc_java_lang_Object$type,
	&_jc_long$prim$type,
	&_jc_int$prim$type
};

_jc_method _jc_java_lang_VMObject$method_info$wait$f4b3db53c17f3f59 = {
	.name=			"wait",
	.signature=		"(Ljava/lang/Object;JI)V",
	.class=			&_jc_java_lang_VMObject$type,
	.param_types=		&_jc_java_lang_VMObject$param_types$wait$f4b3db53c17f3f59,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_lang_VMObject$param_ptypes$wait$f4b3db53c17f3f59,
	.signature_hash=	_JC_JLONG(0xf4b3db53c17f3f59),
	.access_flags=		_JC_ACC_STATIC|_JC_ACC_FINAL|_JC_ACC_NATIVE,
	.function=		&_jc_java_lang_VMObject$method$wait$f4b3db53c17f3f59,
	.num_parameters=	3,
	.num_exceptions=	2,
	.exceptions=		&_jc_java_lang_VMObject$exceptions$wait$f4b3db53c17f3f59,
};

void
_jc_java_lang_VMObject$method$wait$f4b3db53c17f3f59(_jc_env *const env, _jc_java_lang_Object$object *param0, jlong param1, jint param2)
{
	_jc_value retval;

	_JC_INVOKE_NATIVE_METHOD(env, &_jc_java_lang_VMObject$method_info$wait$f4b3db53c17f3f59, &retval, param0, param1, param2);
}

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>()
//

static _jc_linenum _jc_java_lang_VMObject$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_java_lang_VMObject$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_java_lang_VMObject$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_java_lang_VMObject$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_lang_VMObject$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		0,
	.function=		&_jc_java_lang_VMObject$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_lang_VMObject$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_lang_VMObject, _init$52f4ad9f2989aeee);

void
_jc_java_lang_VMObject$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_java_lang_VMObject$object *this)
{
	struct _jc_java_lang_VMObject$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(47);				// 0
	return;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_java_lang_VMObject$methods[] = {
	&_jc_java_lang_VMObject$method_info$_init$52f4ad9f2989aeee,
	&_jc_java_lang_VMObject$method_info$clone$3943fce805d80b70,
	&_jc_java_lang_VMObject$method_info$notify$9552b108446647d4,
	&_jc_java_lang_VMObject$method_info$notifyAll$82e8779c36c7e7ef,
	&_jc_java_lang_VMObject$method_info$wait$f4b3db53c17f3f59
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_java_lang_VMObject$instanceof_hash_bucket_73[] = {
	&_jc_java_lang_VMObject$type,
	_JC_NULL
};
static _jc_type *const _jc_java_lang_VMObject$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_java_lang_VMObject$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[73]=	_jc_java_lang_VMObject$instanceof_hash_bucket_73,
	[113]=	_jc_java_lang_VMObject$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_java_lang_VMObject$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Cloneable",	_JC_JLONG(0x9b667b09132be893) },
	{ "java/lang/IllegalMonitorStateException",	_JC_JLONG(0x252c536250e0b800) },
	{ "java/lang/InterruptedException",	_JC_JLONG(0xdd778e751571cfa9) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_java_lang_VMObject$vtype _jc_java_lang_VMObject$type = {
    .type= {
	.name=			"java/lang/VMObject",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_FINAL,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		11,
		.hash=			_JC_JLONG(0x1f3c3a590189dfc9),
		.source_file=		"VMObject.java",
		.instance_size=		sizeof(_jc_java_lang_VMObject$refs) + sizeof(_jc_java_lang_VMObject$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_java_lang_VMObject$methods) / sizeof(*_jc_java_lang_VMObject$methods),
		.methods=		_jc_java_lang_VMObject$methods,
		.instanceof_hash_table=	_jc_java_lang_VMObject$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_java_lang_VMObject$class_depends) / sizeof(*_jc_java_lang_VMObject$class_depends),
		.class_depends=		_jc_java_lang_VMObject$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_lang_VMObject= {
	},
    }
};

==> jc-1.4.5.tar.gz: java/lang/VMObject.c <==
// final class java.lang.VMObject

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 9b667b09132be893 java_lang_Cloneable
// @dep_class 252c536250e0b800 java_lang_IllegalMonitorStateException
// @dep_class dd778e751571cfa9 java_lang_InterruptedException
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 312e45ed214d432f java_lang_VMObject

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_Cloneable
// @dep_header java_lang_IllegalMonitorStateException
// @dep_header java_lang_InterruptedException
// @dep_header java_lang_String
// @dep_header java_lang_VMObject

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/Cloneable.h"
#include "java/lang/IllegalMonitorStateException.h"
#include "java/lang/InterruptedException.h"
#include "java/lang/String.h"
#include "java/lang/VMObject.h"

/************************************************************************
 *			      Static methods				*
 ************************************************************************/

//
// static final native java.lang.Object clone(java.lang.Cloneable)
//

static const unsigned char _jc_java_lang_VMObject$param_ptypes$clone$3943fce805d80b70[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_java_lang_VMObject$param_types$clone$3943fce805d80b70[] = {
	&_jc_java_lang_Cloneable$type
};

_jc_method _jc_java_lang_VMObject$method_info$clone$3943fce805d80b70 = {
	.name=			"clone",
	.signature=		"(Ljava/lang/Cloneable;)Ljava/lang/Object;",
	.class=			&_jc_java_lang_VMObject$type,
	.param_types=		&_jc_java_lang_VMObject$param_types$clone$3943fce805d80b70,
	.return_type=		&_jc_java_lang_Object$type,
	.param_ptypes=		&_jc_java_lang_VMObject$param_ptypes$clone$3943fce805d80b70,
	.signature_hash=	_JC_JLONG(0x3943fce805d80b70),
	.access_flags=		_JC_ACC_STATIC|_JC_ACC_FINAL|_JC_ACC_NATIVE,
	.function=		&_jc_java_lang_VMObject$method$clone$3943fce805d80b70,
	.num_parameters=	1,
};

_jc_java_lang_Object$object * _JC_JCNI_ATTR
_jc_java_lang_VMObject$method$clone$3943fce805d80b70(_jc_env *const env, _jc_object *param0)
{
	_jc_value retval;

	_JC_INVOKE_NATIVE_METHOD(env, &_jc_java_lang_VMObject$method_info$clone$3943fce805d80b70, &retval, param0);
	return retval.l;
}

//
// static final native java.lang.Class getClass(java.lang.Object)
//

static const unsigned char _jc_java_lang_VMObject$param_ptypes$getClass$2be11d215bfbfbfe[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_java_lang_VMObject$param_types$getClass$2be11d215bfbfbfe[] = {
	&_jc_java_lang_Object$type
};

_jc_method _jc_java_lang_VMObject$method_info$getClass$2be11d215bfbfbfe = {
	.name=			"getClass",
	.signature=		"(Ljava/lang/Object;)Ljava/lang/Class;",
	.class=			&_jc_java_lang_VMObject$type,
	.param_types=		&_jc_java_lang_VMObject$param_types$getClass$2be11d215bfbfbfe,
	.return_type=		&_jc_java_lang_Class$type,
	.param_ptypes=		&_jc_java_lang_VMObject$param_ptypes$getClass$2be11d215bfbfbfe,
	.signature_hash=	_JC_JLONG(0x2be11d215bfbfbfe),
	.access_flags=		_JC_ACC_STATIC|_JC_ACC_FINAL|_JC_ACC_NATIVE,
	.function=		&_jc_java_lang_VMObject$method$getClass$2be11d215bfbfbfe,
	.num_parameters=	1,
};

_jc_java_lang_Class$object * _JC_JCNI_ATTR
_jc_java_lang_VMObject$method$getClass$2be11d215bfbfbfe(_jc_env *const env, _jc_java_lang_Object$object *param0)
{
	_jc_value retval;

	_JC_INVOKE_NATIVE_METHOD(env, &_jc_java_lang_VMObject$method_info$getClass$2be11d215bfbfbfe, &retval, param0);
	return retval.l;
}

//
// static final native void notify(java.lang.Object) throws java.lang.IllegalMonitorStateException
//

static const unsigned char _jc_java_lang_VMObject$param_ptypes$notify$9552b108446647d4[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_java_lang_VMObject$exceptions$notify$9552b108446647d4[] = {
	&_jc_java_lang_IllegalMonitorStateException$type
};

static _jc_type *const _jc_java_lang_VMObject$param_types$notify$9552b108446647d4[] = {
	&_jc_java_lang_Object$type
};

_jc_method _jc_java_lang_VMObject$method_info$notify$9552b108446647d4 = {
	.name=			"notify",
	.signature=		"(Ljava/lang/Object;)V",
	.class=			&_jc_java_lang_VMObject$type,
	.param_types=		&_jc_java_lang_VMObject$param_types$notify$9552b108446647d4,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_lang_VMObject$param_ptypes$notify$9552b108446647d4,
	.signature_hash=	_JC_JLONG(0x9552b108446647d4),
	.access_flags=		_JC_ACC_STATIC|_JC_ACC_FINAL|_JC_ACC_NATIVE,
	.function=		&_jc_java_lang_VMObject$method$notify$9552b108446647d4,
	.num_parameters=	1,
	.num_exceptions=	1,
	.exceptions=		&_jc_java_lang_VMObject$exceptions$notify$9552b108446647d4,
};

void _JC_JCNI_ATTR
_jc_java_lang_VMObject$method$notify$9552b108446647d4(_jc_env *const env, _jc_java_lang_Object$object *param0)
{
	_jc_value retval;

	_JC_INVOKE_NATIVE_METHOD(env, &_jc_java_lang_VMObject$method_info$notify$9552b108446647d4, &retval, param0);
}

//
// static final native void notifyAll(java.lang.Object) throws java.lang.IllegalMonitorStateException
//

static const unsigned char _jc_java_lang_VMObject$param_ptypes$notifyAll$82e8779c36c7e7ef[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_java_lang_VMObject$exceptions$notifyAll$82e8779c36c7e7ef[] = {
	&_jc_java_lang_IllegalMonitorStateException$type
};

static _jc_type *const _jc_java_lang_VMObject$param_types$notifyAll$82e8779c36c7e7ef[] = {
	&_jc_java_lang_Object$type
};

_jc_method _jc_java_lang_VMObject$method_info$notifyAll$82e8779c36c7e7ef = {
	.name=			"notifyAll",
	.signature=		"(Ljava/lang/Object;)V",
	.class=			&_jc_java_lang_VMObject$type,
	.param_types=		&_jc_java_lang_VMObject$param_types$notifyAll$82e8779c36c7e7ef,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_lang_VMObject$param_ptypes$notifyAll$82e8779c36c7e7ef,
	.signature_hash=	_JC_JLONG(0x82e8779c36c7e7ef),
	.access_flags=		_JC_ACC_STATIC|_JC_ACC_FINAL|_JC_ACC_NATIVE,
	.function=		&_jc_java_lang_VMObject$method$notifyAll$82e8779c36c7e7ef,
	.num_parameters=	1,
	.num_exceptions=	1,
	.exceptions=		&_jc_java_lang_VMObject$exceptions$notifyAll$82e8779c36c7e7ef,
};

void _JC_JCNI_ATTR
_jc_java_lang_VMObject$method$notifyAll$82e8779c36c7e7ef(_jc_env *const env, _jc_java_lang_Object$object *param0)
{
	_jc_value retval;

	_JC_INVOKE_NATIVE_METHOD(env, &_jc_java_lang_VMObject$method_info$notifyAll$82e8779c36c7e7ef, &retval, param0);
}

//
// static final native void wait(java.lang.Object, long, int) throws java.lang.IllegalMonitorStateException, java.lang.InterruptedException
//

static const unsigned char _jc_java_lang_VMObject$param_ptypes$wait$f4b3db53c17f3f59[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_LONG, _JC_TYPE_INT, _JC_TYPE_VOID };

static _jc_type *const _jc_java_lang_VMObject$exceptions$wait$f4b3db53c17f3f59[] = {
	&_jc_java_lang_IllegalMonitorStateException$type,
	&_jc_java_lang_InterruptedException$type
};

static _jc_type *const _jc_java_lang_VMObject$param_types$wait$f4b3db53c17f3f59[] = {
	&_jc_java_lang_Object$type,
	&_jc_long$prim$type,
	&_jc_int$prim$type
};

_jc_method _jc_java_lang_VMObject$method_info$wait$f4b3db53c17f3f59 = {
	.name=			"wait",
	.signature=		"(Ljava/lang/Object;JI)V",
	.class=			&_jc_java_lang_VMObject$type,
	.param_types=		&_jc_java_lang_VMObject$param_types$wait$f4b3db53c17f3f59,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_lang_VMObject$param_ptypes$wait$f4b3db53c17f3f59,
	.signature_hash=	_JC_JLONG(0xf4b3db53c17f3f59),
	.access_flags=		_JC_ACC_STATIC|_JC_ACC_FINAL|_JC_ACC_NATIVE,
	.function=		&_jc_java_lang_VMObject$method$wait$f4b3db53c17f3f59,
	.num_parameters=	3,
	.num_exceptions=	2,
	.exceptions=		&_jc_java_lang_VMObject$exceptions$wait$f4b3db53c17f3f59,
};

void _JC_JCNI_ATTR
_jc_java_lang_VMObject$method$wait$f4b3db53c17f3f59(_jc_env *const env, _jc_java_lang_Object$object *param0, jlong param1, jint param2)
{
	_jc_value retval;

	_JC_INVOKE_NATIVE_METHOD(env, &_jc_java_lang_VMObject$method_info$wait$f4b3db53c17f3f59, &retval, param0, param1, param2);
}

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>()
//

static _jc_linenum _jc_java_lang_VMObject$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_java_lang_VMObject$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_java_lang_VMObject$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_java_lang_VMObject$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_lang_VMObject$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		0,
	.function=		&_jc_java_lang_VMObject$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_lang_VMObject$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_lang_VMObject, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_java_lang_VMObject$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_java_lang_VMObject$object *this)
{
	struct _jc_java_lang_VMObject$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(47);				// 0
	return;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_java_lang_VMObject$methods[] = {
	&_jc_java_lang_VMObject$method_info$_init$52f4ad9f2989aeee,
	&_jc_java_lang_VMObject$method_info$clone$3943fce805d80b70,
	&_jc_java_lang_VMObject$method_info$getClass$2be11d215bfbfbfe,
	&_jc_java_lang_VMObject$method_info$notify$9552b108446647d4,
	&_jc_java_lang_VMObject$method_info$notifyAll$82e8779c36c7e7ef,
	&_jc_java_lang_VMObject$method_info$wait$f4b3db53c17f3f59
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_java_lang_VMObject$instanceof_hash_bucket_47[] = {
	&_jc_java_lang_VMObject$type,
	_JC_NULL
};
static _jc_type *const _jc_java_lang_VMObject$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_java_lang_VMObject$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[47]=	_jc_java_lang_VMObject$instanceof_hash_bucket_47,
	[101]=	_jc_java_lang_VMObject$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_java_lang_VMObject$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Cloneable",	_JC_JLONG(0x9b667b09132be893) },
	{ "java/lang/IllegalMonitorStateException",	_JC_JLONG(0x252c536250e0b800) },
	{ "java/lang/InterruptedException",	_JC_JLONG(0xdd778e751571cfa9) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_java_lang_VMObject$vtype _jc_java_lang_VMObject$type = {
    .type= {
	.name=			"java/lang/VMObject",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_FINAL,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		11,
		.hash=			_JC_JLONG(0x312e45ed214d432f),
		.source_file=		"VMObject.java",
		.instance_size=		sizeof(_jc_java_lang_VMObject$refs) + sizeof(_jc_java_lang_VMObject$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_java_lang_VMObject$methods) / sizeof(*_jc_java_lang_VMObject$methods),
		.methods=		_jc_java_lang_VMObject$methods,
		.instanceof_hash_table=	_jc_java_lang_VMObject$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_java_lang_VMObject$class_depends) / sizeof(*_jc_java_lang_VMObject$class_depends),
		.class_depends=		_jc_java_lang_VMObject$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_lang_VMObject= {
	},
    }
};
